package de.hendriklipka.pdfconv;

import org.jpedal.PdfDecoder;
import org.jpedal.io.ObjectStore;

import java.io.File;
import java.awt.image.BufferedImage;
import java.awt.image.AffineTransformOp;
import java.awt.geom.AffineTransform;

public class PDFConv
{
    private String _pdfName;
    private String _baseName;

    public PDFConv(String pdfName, String baseName)
    {
        _pdfName=pdfName;
        _baseName=baseName;
    }

    public static void main(String[] args)
    {
        if (2!=args.length)
        {
            System.out.println("usage: java PDFConv PDFFILE IMAGEBASENAME");
            System.exit(1);
        }
        String pdfName=args[0];
        String baseName=args[1];
        PDFConv pc=new PDFConv(pdfName,baseName);
        pc.convert();
    }

    private void convert()
    {
		PdfDecoder pdfDecoder = null;

		//initialise objectStore which we will use for storing images
		//"demo" is just a unique key for this instance when storing data in temp
		ObjectStore.init( "pdfconv" );


		String targetDir = "./output/";

		//create a directory if it doesn't exist
		File targetPath = new File( targetDir );
		if( !targetPath.exists())
			targetPath.mkdirs();

		//PdfDecoder returns a PdfException if there is a problem
		try
		{
			pdfDecoder = new PdfDecoder( true );

			System.out.println( "converting PDF file:" + _pdfName );
			pdfDecoder.openPdfFile( _pdfName );
		}
		catch( Exception ex )
		{
            System.err.println( "Error while opening PDF file" );
            ex.printStackTrace();
			System.exit( 1 );
		}

		try
		{
			for( int page = 1; page <= pdfDecoder.getPageCount(); page++ )
			{ 
                System.out.println("converting page "+page);
				pdfDecoder.initDisplay( page );
				pdfDecoder.decodePage( true, page );

				String targetName = _baseName+"_page_" + page;
				try
				{
					BufferedImage targetImage = pdfDecoder.getPageAsImage();
					if( null==targetImage )
                    {
						System.err.println( "can't render page, skipping" );
                    }
					else
					{
						AffineTransform at = new AffineTransform();
                        // if scaling should be needed, do it here
                        // maybe we have a fixed target size, and scale the image accordingly
                        // flipping the image is needed only for jpedal>=1.82
//						at.scale( 1, -1 ); // flip image upside-down
//                        at.translate(0,-targetImage.getHeight());
//						AffineTransformOp ato = new AffineTransformOp( at, null );
//						targetImage = ato.filter( targetImage, null );
						ObjectStore.saveStoredImage( targetDir+targetName, targetImage, true, false, "jpg" );
					}
				}
				catch( Exception ex )
				{
					System.err.println( "Error while writing image" );
                    ex.printStackTrace();
				}
                // free memory
				pdfDecoder.clearPdfImageData();
                System.gc();
			}
		}
		catch( Exception ex )
		{
			pdfDecoder.closePdfFile();
			System.err.println( "Error while executing ");
            ex.printStackTrace();
			System.exit( 1 );
		}
        // free all remaining data
		pdfDecoder.markAllPagesAsUnread();
		pdfDecoder.flushObjectValues( false ); //flush any text data read
		pdfDecoder.closePdfFile();
		ObjectStore.flush();         
    }
}
